==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.equipmentgeneration_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.equipmentgeneration_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link EquipmentGeneration }
     * 
     */
    public EquipmentGeneration createEquipmentGeneration() {
        return new EquipmentGeneration();
    }

    /**
     * Create an instance of {@link EquipmentDetails }
     * 
     */
    public EquipmentDetails createEquipmentDetails() {
        return new EquipmentDetails();
    }

    /**
     * Create an instance of {@link PMScheduleandMaintenancePatternDetails }
     * 
     */
    public PMScheduleandMaintenancePatternDetails createPMScheduleandMaintenancePatternDetails() {
        return new PMScheduleandMaintenancePatternDetails();
    }

    /**
     * Create an instance of {@link CommissioningWorkOrderDetails }
     * 
     */
    public CommissioningWorkOrderDetails createCommissioningWorkOrderDetails() {
        return new CommissioningWorkOrderDetails();
    }

    /**
     * Create an instance of {@link CreateEquipmentStructure }
     * 
     */
    public CreateEquipmentStructure createCreateEquipmentStructure() {
        return new CreateEquipmentStructure();
    }

    /**
     * Create an instance of {@link CopyData }
     * 
     */
    public CopyData createCopyData() {
        return new CopyData();
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.equipmentgeneration_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.equipmentgeneration_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link EquipmentGeneration }
     * 
     * @return
     *     the new instance of {@link EquipmentGeneration }
     */
    public EquipmentGeneration createEquipmentGeneration() {
        return new EquipmentGeneration();
    }

    /**
     * Create an instance of {@link EquipmentDetails }
     * 
     * @return
     *     the new instance of {@link EquipmentDetails }
     */
    public EquipmentDetails createEquipmentDetails() {
        return new EquipmentDetails();
    }

    /**
     * Create an instance of {@link PMScheduleandMaintenancePatternDetails }
     * 
     * @return
     *     the new instance of {@link PMScheduleandMaintenancePatternDetails }
     */
    public PMScheduleandMaintenancePatternDetails createPMScheduleandMaintenancePatternDetails() {
        return new PMScheduleandMaintenancePatternDetails();
    }

    /**
     * Create an instance of {@link CommissioningWorkOrderDetails }
     * 
     * @return
     *     the new instance of {@link CommissioningWorkOrderDetails }
     */
    public CommissioningWorkOrderDetails createCommissioningWorkOrderDetails() {
        return new CommissioningWorkOrderDetails();
    }

    /**
     * Create an instance of {@link CreateEquipmentStructure }
     * 
     * @return
     *     the new instance of {@link CreateEquipmentStructure }
     */
    public CreateEquipmentStructure createCreateEquipmentStructure() {
        return new CreateEquipmentStructure();
    }

    /**
     * Create an instance of {@link CopyData }
     * 
     * @return
     *     the new instance of {@link CopyData }
     */
    public CopyData createCopyData() {
        return new CopyData();
    }

}
